/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.accumulo.core.client.replication;

/**
 * The peer already exists
 */
public class PeerNotFoundException extends Exception {
  private static final long serialVersionUID = 1L;

  public PeerNotFoundException(String peer) {
    this(peer, (String) null);
  }

  public PeerNotFoundException(String peer, String message) {
    super("Peer '" + peer + "' not found " + (message == null || message.isEmpty() ? "" : message));
  }

  public PeerNotFoundException(String message, Throwable cause) {
    super(message, cause);
  }

  public PeerNotFoundException(String peer, String message, Throwable cause) {
    super("Peer '" + peer + "' not found " + message, cause);
  }
}
